@@ -68,4 +68,10 @@ class HTMLFormatter(BaseFormatter):
     MODE = "html"
 
     def format(self, record):
-        return record
\ No newline at end of file
+        """
+        Properly escape all the string values of message
+        """
+        for key, value in record.__dict__.items():
+            if isinstance(value, str):
+                setattr(record, key, value.replace('&', '&amp;').replace('<', '&lt;').replace('>', '&gt;'))
+        return super().format(record)
